@@ -11,6 +11,7 @@
 #' @template ret_learner
 #' @export
 #' @family costsens
+#' @family wrapper
 #' @aliases CostSensRegrWrapper CostSensRegrModel
 makeCostSensRegrWrapper = function(learner) {
   learner = checkLearnerRegr(learner)
@@ -41,7 +42,6 @@ trainLearner.CostSensRegrWrapper = function(.learner, .task, .subset, ...) {
   makeChainModel(next.model = models, cl = "CostSensRegrModel")
 }
 
-
 #' @export
 predictLearner.CostSensRegrWrapper = function(.learner, .model, .newdata, ...) {
   classes = .model$task.desc$class.levels
@@ -49,6 +49,7 @@ predictLearner.CostSensRegrWrapper = function(.learner, .model, .newdata, ...) {
   preds = sapply(models, function(mod) {
     predict(mod, newdata = .newdata, ...)$data$response
   })
+  # FIXME: this will break for length(models) == 1? do not use sapply!
   preds = apply(preds, 1L, getMinIndex)
   return(factor(classes[preds], levels = classes))
 }
@@ -59,8 +60,7 @@ makeWrappedModel.CostSensRegrWrapper = function(learner, learner.model, task.des
   factor.levels, time) {
 
   x = NextMethod()
-  class(x) = c("CostSensRegrModel", class(x))
-  return(x)
+  addClasses(x, "CostSensRegrModel")
 }
 
 
@@ -82,5 +82,3 @@ getCostSensRegrModels = function(model, learner.models = FALSE) {
   else
     ms
 }
-
-
