@@ -1,6 +1,6 @@
 #' @export
 #' @rdname FeatSelControl
-makeFeatSelControlSequential = function(same.resampling.instance = TRUE, impute.val = Inf, method,
+makeFeatSelControlSequential = function(same.resampling.instance = TRUE, impute.val = NULL, method,
   alpha = 0.01, beta = -0.001, maxit = NA_integer_, max.features = NA_integer_) {
 
   makeFeatSelControl(
