@@ -13,14 +13,17 @@ makeRLearner.classif.LiblineaRBinary = function() {
       makeIntegerLearnerParam(id = "cross", default = 0L, lower = 0L),
       makeLogicalLearnerParam(id = "verbose", default = FALSE)
     ),
-    properties = c("twoclass", "numerics")
+    properties = c("twoclass", "numerics"),
+    name = "Regularized Binary Linear Predictive Models Estimation",
+    short.name = "liblinearbinary",
+    note = "This model subsumes the types 1,2,3,5."
   )
 }
 
 #' @export
 trainLearner.classif.LiblineaRBinary = function(.learner, .task, .subset, .weights = NULL, ...) {
   d = getTaskData(.task, .subset, target.extra = TRUE)
-  LiblineaR(data = d$data, labels = d$target, ...)
+  LiblineaR::LiblineaR(data = d$data, labels = d$target, ...)
 }
 
 #' @export
