@@ -4,7 +4,7 @@ makeRLearner.classif.blackboost = function() {
     cl = "classif.blackboost",
     package = c("mboost", "party"),
     par.set = makeParamSet(
-      makeDiscreteLearnerParam(id = "family", default = Binomial(), values = list(AdaExp = AdaExp(), Binomial = Binomial())),
+      makeDiscreteLearnerParam(id = "family", default = mboost::Binomial(), values = list(AdaExp = mboost::AdaExp(), Binomial = mboost::Binomial())),
       makeIntegerLearnerParam(id = "mstop", default = 100L, lower = 1L),
       makeNumericLearnerParam(id = "nu", default = 0.1, lower = 0, upper = 1),
       makeDiscreteLearnerParam(id = "risk", default = "inbag", values = c("inbag", "oobag", "none")),
@@ -20,20 +20,23 @@ makeRLearner.classif.blackboost = function() {
       makeLogicalLearnerParam(id = "savesplitstats", default = TRUE),
       makeIntegerLearnerParam(id = "maxdepth", default = 0L, lower = 0L)
     ),
-    par.vals = list(family = Binomial()),
-    properties = c("twoclass", "missings", "numerics", "factors", "prob", "weights")
+    par.vals = list(family = mboost::Binomial()),
+    properties = c("twoclass", "missings", "numerics", "factors", "prob", "weights"),
+    name = "Gradient Boosting With Regression Trees",
+    short.name = "blackbst",
+    note = ""
   )
 }
 
 #' @export
 trainLearner.classif.blackboost = function(.learner, .task, .subset, .weights = NULL, mstop, nu, risk, teststat, testtype, mincriterion, maxdepth, ...) {
-  ctrl = learnerArgsToControl(boost_control, mstop, nu, risk)
-  tc = learnerArgsToControl(ctree_control, teststat, testtype, mincriterion, maxdepth)
+  ctrl = learnerArgsToControl(mboost::boost_control, mstop, nu, risk)
+  tc = learnerArgsToControl(party::ctree_control, teststat, testtype, mincriterion, maxdepth)
   f = getTaskFormula(.task)
   if (!is.null(.weights))
-    blackboost(f, data = getTaskData(.task, .subset), control = ctrl, tree_controls = tc, weights = .weights, ...)
+    mboost::blackboost(f, data = getTaskData(.task, .subset), control = ctrl, tree_controls = tc, weights = .weights, ...)
   else
-    blackboost(f, data = getTaskData(.task, .subset), control = ctrl, tree_controls = tc, ...)
+    mboost::blackboost(f, data = getTaskData(.task, .subset), control = ctrl, tree_controls = tc, ...)
 }
 
 #' @export
@@ -43,8 +46,8 @@ predictLearner.classif.blackboost = function(.learner, .model, .newdata, ...) {
   if (.learner$predict.type == "prob") {
     y = matrix(0, ncol = 2L, nrow = nrow(.newdata))
     colnames(y) = .model$task.desc$class.levels
-    y[,1L] = p
-    y[,2L] = 1-p
+    y[, 1L] = p
+    y[, 2L] = 1-p
     return(y)
   } else {
     return(p)
