@@ -12,8 +12,8 @@ makeRLearner.classif.cforest = function() {
       makeDiscreteLearnerParam(id = "teststat", values = c("quad", "max"), default = "quad"),
       makeLogicalLearnerParam(id = "pvalue", default = TRUE),
       makeDiscreteLearnerParam(id = "testtype",
-                               values = c("Bonferroni", "MonteCarlo", "Univariate", "Teststatistic"),
-                               default = "Univariate"),
+        values = c("Bonferroni", "MonteCarlo", "Univariate", "Teststatistic"),
+        default = "Univariate"),
       makeNumericLearnerParam(id = "mincriterion", lower = 0, default = 0),
       makeNumericLearnerParam(id = "minprob", lower = 0, default = 0.01),
       makeIntegerLearnerParam(id = "minsplit", lower = 1L, default = 20L),
@@ -25,35 +25,39 @@ makeRLearner.classif.cforest = function() {
       makeIntegerLearnerParam(id = "maxdepth", lower = 0L, default = 0L),
       makeLogicalLearnerParam(id = "savesplitstats", default = FALSE)
     ),
-    properties = c("twoclass", "multiclass", "prob", "factors", "numerics", "weights"),
-    par.vals = list()
+    properties = c("twoclass", "multiclass", "prob", "factors", "numerics", "ordered", "weights"),
+    par.vals = list(),
+    name = "Random forest based on conditional inference trees",
+    short.name = "cforest",
+    note = ""
   )
 }
 
 #' @export
 trainLearner.classif.cforest = function(.learner, .task, .subset, .weights = NULL,
-                                     ntree, mtry, replace, fraction, trace, pvalue, 
+                                     ntree, mtry, replace, fraction, trace, pvalue,
                                      teststat, testtype, mincriterion, minprob,
                                      minsplit, minbucket, stump, randomsplits,
                                      nresample, maxsurrogate, maxdepth,
                                      savesplitstats, ...) {
   f = getTaskFormula(.task)
   d = getTaskData(.task, .subset)
-  ctrl = learnerArgsToControl(cforest_unbiased, ntree, mtry, replace, fraction,
+  ctrl = learnerArgsToControl(party::cforest_unbiased, ntree, mtry, replace, fraction,
                               trace, pvalue, teststat, testtype, mincriterion,
                               minprob, minsplit, minbucket, stump, randomsplits,
                               nresample, maxsurrogate, maxdepth, savesplitstats)
-  cforest(f, data = d, controls = ctrl, weights = .weights, ...)
+  party::cforest(f, data = d, controls = ctrl, weights = .weights, ...)
 }
 
 #' @export
 predictLearner.classif.cforest = function(.learner, .model, .newdata, ...) {
   if (.learner$predict.type == "prob") {
     p = predict(.model$learner.model, newdata = .newdata, type = "prob", ...)
+    # FIXME: this will break for nrow(.newdata) == 1? do not use sapply!
     p = t(sapply(p, "["))
     colnames(p) = .model$task.desc$class.levels
   } else {
-    p = predict(.model$learner.model, newdata = .newdata, ...) 
+    p = predict(.model$learner.model, newdata = .newdata, ...)
   }
   p
 }
