@@ -12,7 +12,10 @@ makeRLearner.classif.gbm = function() {
       makeNumericLearnerParam(id = "bag.fraction", default = 0.5, lower = 0, upper = 1),
       makeNumericLearnerParam(id = "train.fraction", default = 1, lower = 0, upper = 1)
     ),
-    properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob", "weights")
+    properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob", "weights"),
+    name = "Gradient Boosting Machine",
+    short.name = "gbm",
+    note = ""
   )
 }
 
@@ -24,10 +27,10 @@ trainLearner.classif.gbm = function(.learner, .task, .subset, .weights = NULL,
     d = getTaskData(.task, .subset)
   if (is.null(.weights)) {
     f = getTaskFormula(.task)
-    gbm(f, data = d, keep.data = FALSE, verbose = FALSE, ...)
+    gbm::gbm(f, data = d, keep.data = FALSE, verbose = FALSE, ...)
   } else  {
     f = as.formula(getTaskFormulaAsString(.task))
-    gbm(f, data = d, keep.data = FALSE, verbose = FALSE, weights = .weights, ...)
+    gbm::gbm(f, data = d, keep.data = FALSE, verbose = FALSE, weights = .weights, ...)
   }
 }
 
@@ -40,8 +43,8 @@ predictLearner.classif.gbm = function(.learner, .model, .newdata, ...) {
     if (.learner$predict.type == "prob") {
       y = matrix(0, ncol = 2, nrow = nrow(.newdata))
       colnames(y) = levs
-      y[,1L] = 1-p
-      y[,2L] = p
+      y[, 1L] = 1-p
+      y[, 2L] = p
       return(y)
     } else {
       p = as.factor(ifelse(p > 0.5, levs[2L], levs[1L]))
@@ -49,7 +52,7 @@ predictLearner.classif.gbm = function(.learner, .model, .newdata, ...) {
       return(p)
     }
   } else {
-    p = p[,,1]
+    p = p[,,1L]
     if (.learner$predict.type == "prob") {
       return(p)
     } else {
@@ -58,5 +61,4 @@ predictLearner.classif.gbm = function(.learner, .model, .newdata, ...) {
       return(factor(cns[ind], levels = cns))
     }
   }
-
 }
