@@ -4,20 +4,23 @@ makeRLearner.classif.geoDA = function() {
     cl = "classif.geoDA",
     package = "DiscriMiner",
     par.set = makeParamSet(),
-    properties = c("twoclass", "multiclass", "numerics")
+    properties = c("twoclass", "multiclass", "numerics"),
+    name = "Geometric Predictive Discriminant Analysis",
+    short.name = "geoda",
+    note = ""
   )
 }
 
 #' @export
 trainLearner.classif.geoDA = function(.learner, .task, .subset, .weights = NULL,  ...) {
   d = getTaskData(.task, .subset, target.extra = TRUE)
-  geoDA(variables = d$data, group = d$target, ...)
+  DiscriMiner::geoDA(variables = d$data, group = d$target, ...)
 }
 
 #' @export
 predictLearner.classif.geoDA = function(.learner, .model, .newdata, ...) {
   m = .model$learner.model
-  p = classify(m, newdata = .newdata)
+  p = DiscriMiner::classify(m, newdata = .newdata)
   #p$scores #we loose this information
   p$pred_class
 }
