@@ -10,7 +10,10 @@ makeRLearner.classif.knn = function() {
     ),
     # knn cannot really return probs, only for the winning class (yeah well done BR)
     # knn also cannot handle factors in features apparantly
-    properties = c("twoclass", "multiclass", "numerics")
+    properties = c("twoclass", "multiclass", "numerics"),
+    name = "k-Nearest Neighbor",
+    short.name = "knn",
+    note = ""
   )
 }
 
@@ -24,6 +27,6 @@ trainLearner.classif.knn = function(.learner, .task, .subset, .weights = NULL,
 predictLearner.classif.knn = function(.learner, .model, .newdata, ...) {
   args = .model$learner.model
   args$test = .newdata
-  do.call(knn, args)
+  do.call(class::knn, args)
 }
 
