@@ -4,14 +4,17 @@ makeRLearner.classif.logreg = function() {
     cl = "classif.logreg",
     package = "stats",
     par.set = makeParamSet(),
-    properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "weights")
+    properties = c("twoclass", "numerics", "factors", "prob", "weights"),
+    name = "Logistic Regression",
+    short.name = "logreg",
+    note = ""
   )
 }
 
 #' @export
 trainLearner.classif.logreg = function(.learner, .task, .subset, .weights = NULL,  ...) {
   f = getTaskFormula(.task)
-  glm(f, data = getTaskData(.task, .subset), model = FALSE, family = "binomial", ...)
+  stats::glm(f, data = getTaskData(.task, .subset), model = FALSE, family = "binomial", ...)
 }
 
 #' @export
@@ -19,11 +22,11 @@ predictLearner.classif.logreg = function(.learner, .model, .newdata, ...) {
   x = predict(.model$learner.model, newdata = .newdata, type = "response", ...)
   levs = .model$task.desc$class.levels
   if (.learner$predict.type == "prob") {
-    # FIXME this should be a helper function
+    # FIXME: this should be a helper function
     y = matrix(0, ncol = 2L, nrow = nrow(.newdata))
     colnames(y) = levs
-    y[,1L] = 1-x
-    y[,2L] = x
+    y[, 1L] = 1-x
+    y[, 2L] = x
     return(y)
   } else {
     levs = .model$task.desc$class.levels
