@@ -8,21 +8,24 @@ makeRLearner.classif.mda = function() {
       makeUntypedLearnerParam(id = "subclasses", default = 2L),
       makeIntegerLearnerParam(id = "iter", default = 5L, lower = 1L),
       makeIntegerLearnerParam(id = "dimension", lower = 1L),
-      makeDiscreteLearnerParam(id = "method", default = polyreg,
-        values = list(polyreg = polyreg, mars = mars, bruto = bruto, gen.ridge = gen.ridge)),
+      makeDiscreteLearnerParam(id = "method", default = mda::polyreg,
+        values = list(polyreg = mda::polyreg, mars = mda::mars, bruto = mda::bruto, gen.ridge = mda::gen.ridge)),
       makeLogicalLearnerParam(id = "trace", default = FALSE),
       makeLogicalLearnerParam(id = "keep.fitted", default = TRUE),
       makeIntegerLearnerParam(id = "tries", default = 5L, lower = 1L)
     ),
     par.vals = list(keep.fitted = FALSE),
-    properties = c("twoclass", "multiclass", "numerics", "factors", "prob")
+    properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
+    name = "Mixture Discriminant Analysis",
+    short.name = "mda",
+    note = "`keep.fitted` has been set to `FALSE` by default for speed."
   )
 }
 
 #' @export
 trainLearner.classif.mda = function(.learner, .task, .subset, .weights = NULL,  ...) {
   f = getTaskFormula(.task)
-  mda(f, data = getTaskData(.task, .subset), ...)
+  mda::mda(f, data = getTaskData(.task, .subset), ...)
 }
 
 #' @export
