@@ -12,18 +12,20 @@ makeRLearner.regr.IBk = function() {
       makeLogicalLearnerParam(id = "X"),
       makeUntypedLearnerParam(id = "A", default = "weka.core.neighboursearch.LinearNNSearch")
     ),
-    properties = c("twoclass", "multiclass", "numerics", "factors", "prob")
+    properties = c("numerics", "factors"),
+    name = "K-Nearest Neighbours",
+    short.name = "ibk",
+    note = ""
   )
 }
 
 #' @export
 trainLearner.regr.IBk = function(.learner, .task, .subset, .weights = NULL,  ...) {
-  ctrl = Weka_control(...)
-  IBk(getTaskFormula(.task), data = getTaskData(.task, .subset), control = ctrl, na.action = na.pass)
+  ctrl = RWeka::Weka_control(...)
+  RWeka::IBk(getTaskFormula(.task), data = getTaskData(.task, .subset), control = ctrl, na.action = na.pass)
 }
 
 #' @export
 predictLearner.regr.IBk = function(.learner, .model, .newdata, ...) {
-  type = switch(.learner$predict.type, prob = "prob", "class")
-  predict(.model$learner.model, newdata = .newdata, type = type, ...)
+  predict(.model$learner.model, newdata = .newdata, type = "class", ...)
 }
