@@ -1,4 +1,4 @@
-# FIXME document BS options
+# FIXME: document BS options
 
 #' @export
 makeRLearner.regr.randomForest = function() {
@@ -20,11 +20,12 @@ makeRLearner.regr.randomForest = function() {
       makeLogicalLearnerParam(id = "keep.inbag", default = FALSE)
     ),
     par.vals = list(
-      fix.factors = FALSE,
       se.method = "bootstrap",
       nr.of.bootstrap.samples = 5L
     ),
-    properties = c("numerics", "factors", "se")
+    properties = c("numerics", "factors", "ordered", "se"),
+    name = "Random Forest",
+    short.name = "rf"
   )
 }
 
@@ -33,7 +34,7 @@ trainLearner.regr.randomForest = function(.learner, .task, .subset, .weights = N
   f = getTaskFormula(.task)
   par.vals = .learner$par.vals
 
-  m = randomForest(f, data = getTaskData(.task, .subset), ...)
+  m = randomForest::randomForest(f, data = getTaskData(.task, .subset), ...)
 
   # we have to do some preprocessing here if we need the standard error
   if (.learner$predict.type == "se") {
@@ -45,14 +46,14 @@ trainLearner.regr.randomForest = function(.learner, .task, .subset, .weights = N
       bootstrapSize = nrow(train)
 
       # generate bootstrap samples
-      samplesIdx = replicate(numberOfBootstraps, sample(1:bootstrapSize, replace = TRUE))
+      samplesIdx = replicate(numberOfBootstraps, sample(seq_len(bootstrapSize), replace = TRUE))
 
       # determine whether we work with reduced ensemble size (noisy bootstrap) or not
       ntree = if (par.vals$se.method == "bootstrap") par.vals$ntree else par.vals$ntree.for.se
 
       # fit models on the bootstrap samples
       models = apply(samplesIdx, 2, function(bootstrapIdx) {
-        randomForest(f, data = train[bootstrapIdx,],...)
+        randomForest::randomForest(f, data = train[bootstrapIdx,, drop = FALSE],...)
       })
 
       # save models in attrribute
@@ -111,17 +112,17 @@ bootstrapStandardError = function(.learner, .model, .newdata, ...) {
         bias = 0
         for (b in seq_len(B)) {
           for (r in seq_len(R)) {
-            bias = bias + (ind.responses[[b]][i,r] - aggr.responses[i,b])^2
+            bias = bias + (ind.responses[[b]][i, r] - aggr.responses[i,b])^2
           }
         }
 
         bias = bias * const
-        res[i,2L] = res[i,2L] - bias
+        res[i, 2L] = res[i, 2L] - bias
       }
     }
 
     # var --> sd
-    res[,2L] = sqrt(res[,2L])
+    res[, 2L] = sqrt(res[, 2L])
     return(res)
 }
 
@@ -141,15 +142,15 @@ jackknifeStandardError = function(.learner, .model, .newdata, ...) {
 
     # determine number of participating ensembles
     # FIXME: formula looks strange. proof read ALL code in this file!
-    M = lapply(seq_len(n), function(i) sum(abs(inbag[i,]-1)))
+    M = lapply(seq_len(n), function(i) sum(abs(inbag[i, ] - 1)))
     # determine ensemlbe members, where observation i is not included
-    idx = lapply(seq_len(n), function(i) which(inbag[i,] == 0L))
+    idx = lapply(seq_len(n), function(i) which(inbag[i, ] == 0L))
 
     # estimate
     res = matrix(NA_real_, ncol = n, nrow = nrow(.newdata))
     for (j in seq_row(.newdata)) {
       for (i in seq_len(n)) {
-        res[j,i] = sum(rf.preds$individual[j, idx[[i]]]) / M[[i]]
+        res[j, i] = sum(rf.preds$individual[j, idx[[i]]]) / M[[i]]
       }
     }
 
