@@ -1,5 +1,6 @@
-#' Benchmark experiment for multiple learners and tasks.
+#' @title Benchmark experiment for multiple learners and tasks.
 #'
+#' @description
 #' Complete benchmark experiment to compare different learning algorithms across one or more tasks
 #' w.r.t. a given resampling strategy. Experiments are paired, meaning always the same
 #' training / test sets are used for the different learners.
@@ -89,10 +90,8 @@ benchmark = function(learners, tasks, resamplings, measures, show.info = getMlrO
 #'
 #' Container for results of benchmarked experiments using \code{\link{benchmark}}.
 #' The structure of the object itself is rather complicated, it is recommended to
-#' retrive required information via \code{link{getAggrPerformances}}, \code{link{getPredictions}},
-#' \code{\link{getPerformances}}, \code{\link{getFeatSelResult}}, \code{\link{getTuneResult}} or
-#' \code{\link{getFilterResult}}. Alternatively, you can convert the object using
-#' \code{\link[base]{as.data.frame}}
+#' retrive required information via the \code{getBMR*} getter functions.
+#' You can also convert the object using \code{\link[base]{as.data.frame}}.
 #'
 #' @name BenchmarkResult
 #' @rdname BenchmarkResult
@@ -111,35 +110,26 @@ benchmarkParallel = function(index, learners, tasks, resamplings, measures, show
   } else if("TuneWrapper" %in% cl) {
     extract.this = getTuneResult
   } else if("FilterWrapper" %in% cl) {
-    extract.this = getFilterResult
+    extract.this = getFilteredFeatures
   } else {
     extract.this = function(model) { NULL }
   }
-  resample(learners[[ind.learner]], tasks[[ind.task]], resamplings[[ind.task]],
+  lrn = learners[[ind.learner]]
+  r = resample(learners[[ind.learner]], tasks[[ind.task]], resamplings[[ind.task]],
     measures = measures, models = TRUE, extract = extract.this, show.info = show.info)
+  # store used learner in result
+  r$learner = lrn
+  return(r)
 }
 
 
 #' @export
 print.BenchmarkResult = function(x, ...) {
-  print(getAggrPerformances.BenchmarkResult(x))
+  print(getBMRAggrPerformances(x, as.df = TRUE))
 }
 
 #' @export
 as.data.frame.BenchmarkResult = function(x, ...) {
-  getAggrPerformances.BenchmarkResult(x)
+  getBMRPerformances(x, as.df = TRUE)
 }
 
-
-getExtract = function(object, what, within = "extract") {
-  if(missing(what))
-    what = NULL
-  lapply(object, function(task) {
-    t.res = lapply(task, function(learner) {
-      if (is.null(what) || what %in% class(learner[[within]][[1L]]))
-        learner[[within]]
-      else
-        NULL
-    })
-  })
-}
