@@ -6,7 +6,7 @@ evalOptimizationState = function(learner, task, resampling, measures, par.set, b
   opt.path, show.info, dob, state, remove.nas) {
 
   setSlaveOptions()
-  y = setNames(rep(NA_real_, length(measures)), sapply(measures, measureAggrName))
+  y = setNames(rep(NA_real_, length(measures)), vcapply(measures, measureAggrName))
   errmsg = NA_character_
   exec.time = NA_real_
   set.pars.ok = TRUE
@@ -37,7 +37,7 @@ evalOptimizationState = function(learner, task, resampling, measures, par.set, b
     })
     y = r$aggr
     # sort msgs by iters, so iter1, iter2, ...
-    errmsgs = as.character(t(r$err.msgs[,-1L]))
+    errmsgs = as.character(t(r$err.msgs[, -1L]))
     notna = !is.na(errmsgs)
     if (any(notna))
       errmsg = errmsgs[notna][1L]
@@ -73,7 +73,7 @@ evalOptimizationStates = function(learner, task, resampling, measures, par.set,
   # add stuff to opt.path
   for (i in seq_len(n)) {
     res = res.list[[i]]
-    addOptPathElFixed(opt.path, x = as.list(states[[i]]), y = res$y, exec.time = res$exec.time,
+    addOptPathEl(opt.path, x = as.list(states[[i]]), y = res$y, exec.time = res$exec.time,
       error.message = res$errmsg, dob = dobs[i], eol = eols[i], check.feasible = FALSE)
   }
   return(res.list)
