@@ -22,10 +22,26 @@
 #'   and the second column the estimated standard errors.
 #' @export
 predictLearner = function(.learner, .model, .newdata, ...) {
-  UseMethod("predictLearner")
+  lmod = getLearnerModel(.model)
+  if (inherits(lmod, "NoFeaturesModel")) {
+    predict_nofeatures(.model, .newdata)
+  } else {
+    UseMethod("predictLearner")
+  }
 }
 
 predictLearner2 = function(.learner, .model, .newdata, ...) {
+  # if we have that option enabled, set factor levels to complete levels from task
+  if (.learner$fix.factors) {
+    fls = .model$factor.levels
+    ns = names(fls)
+    # only take objects in .newdata
+    ns = intersect(colnames(.newdata), ns)
+    fls = fls[ns]
+    if (length(ns) > 0L)
+      .newdata[ns] = mapply(factor, x = .newdata[ns],
+         levels = fls, SIMPLIFY = FALSE)
+  }
   p = predictLearner(.learner, .model, .newdata, ...)
   p = checkPredictLearnerOutput(.learner, .model, p)
   return(p)
