@@ -1,9 +1,9 @@
 selectFeaturesExhaustive = function(learner, task, resampling, measures, bit.names, bits.to.features, control, opt.path, show.info) {
   p = length(bit.names)
   states = list(rep(0, p))
-  for (i in 1:min(control$max.features, p, na.rm = TRUE)) {
-    x = combn(1:p, i)
-    s = lapply(1:ncol(x), function(j) {
+  for (i in seq_len(min(control$max.features, p, na.rm = TRUE))) {
+    x = combn(seq_len(p), i)
+    s = lapply(seq_col(x), function(j) {
         b = rep(0, p)
         b[x[,j]] = 1
         b
