@@ -5,7 +5,7 @@ selectFeaturesGA = function(learner, task, resampling, measures, bit.names, bits
   lambda = control$extra.args$lambda
   yname = opt.path$y.names[1]
   minimize = opt.path$minimize[1]
-  for (i in 1:mu) {
+  for (i in seq_len(mu)) {
     while(TRUE) {
       states[[i]] = rbinom(length(bit.names), 1, 0.5)
       if(is.na(control$max.features) || sum(states[[i]] <= control$max.features))
@@ -13,12 +13,12 @@ selectFeaturesGA = function(learner, task, resampling, measures, bit.names, bits
     }
   }
   evalOptimizationStatesFeatSel(learner, task, resampling, measures,
-    bits.to.features, control, opt.path, show.info, states, 0L, as.integer(NA))
-  pop.inds = 1:mu
-  for(i in 1:control$maxit) {
+    bits.to.features, control, opt.path, show.info, states, 0L, NA_integer_)
+  pop.inds = seq_len(mu)
+  for(i in seq_len(control$maxit)) {
     # get all mu elements which are alive, ie the current pop and their bit vecs as matrix
-    pop.df = as.data.frame(opt.path)[pop.inds, ]
-    pop.featmat = as.matrix(pop.df[, bit.names]); mode(pop.featmat) = "integer"
+    pop.df = as.data.frame(opt.path)[pop.inds, , drop = FALSE]
+    pop.featmat = as.matrix(pop.df[, bit.names, drop = FALSE]); mode(pop.featmat) = "integer"
     pop.y = pop.df[, yname]
     # create lambda offspring and eval
     kids.list = replicate(lambda, generateKid(pop.featmat, control), simplify = FALSE)
@@ -38,10 +38,10 @@ selectFeaturesGA = function(learner, task, resampling, measures, bit.names, bits
       pool.y = c(pop.y, kids.y)
     }
     # get next pop of best mu from pool
-    pop.inds = pool.inds[order(pool.y, decreasing = !minimize)[1:mu]]
+    pop.inds = pool.inds[order(pool.y, decreasing = !minimize)[seq_len(mu)]]
     setOptPathElEOL(opt.path, setdiff(pool.inds, pop.inds), i)
   }
-  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1]]), ties = "random")
+  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1L]]), ties = "random")
   e = getOptPathEl(opt.path, i)
   makeFeatSelResult(learner, control, names(e$x)[e$x == 1], e$y, opt.path)
 }
@@ -50,9 +50,9 @@ selectFeaturesGA = function(learner, task, resampling, measures, bit.names, bits
 # sample 2 random parents, CX, mutate --> 1 kid
 # (repeat in a loop if max.features not satisfied)
 generateKid = function(featmat, control) {
-  parents = sample(1:nrow(featmat), 2, replace = TRUE)
+  parents = sample(seq_row(featmat), 2L, replace = TRUE)
   while(TRUE) {
-    kid = crossover(featmat[parents[1],], featmat[parents[2],], control$extra.args$crossover.rate)
+    kid = crossover(featmat[parents[1L], ], featmat[parents[2L], ], control$extra.args$crossover.rate)
     kid = mutateBits(kid, control$extra.args$mutation.rate)
     if(is.na(control$max.features) || sum(kid) <= control$max.features)
       break
