@@ -1,11 +1,11 @@
 selectFeaturesRandom = function(learner, task, resampling, measures, bit.names, bits.to.features,
   control, opt.path, show.info) {
 
-  states = lapply(1:control$maxit, function(i) createStates(n = length(bit.names),
+  states = lapply(seq_len(control$maxit), function(i) createStates(n = length(bit.names),
     max.features = control$max.features, prob = control$extra.args$prob))
   evalOptimizationStatesFeatSel(learner, task, resampling, measures, bits.to.features,
-    control, opt.path, show.info, states, 1L, as.integer(NA))
-  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1]]), ties = "random")
+    control, opt.path, show.info, states, 1L, NA_integer_)
+  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1L]]), ties = "random")
   e = getOptPathEl(opt.path, i)
   makeFeatSelResult(learner, control, names(e$x)[e$x == 1], e$y, opt.path)
 }
