@@ -14,6 +14,7 @@
 #'   Classification: \dQuote{response} or \dQuote{prob}.
 #'   Regression: \dQuote{response} or \dQuote{se}.
 #'   Survival: \dQuote{response} (linear predictor) or \dQuote{prob}.
+#'   Clustering: \dQuote{response} or \dQuote{prob}.
 #'   Default is \dQuote{response}.
 #' @template ret_learner
 #' @family predict
@@ -32,7 +33,7 @@ setPredictType.Learner = function(learner, predict.type) {
     regr = c("response", "se"),
     surv = c("response", "prob"),
     costsens = "response",
-    cluster = "response"
+    cluster = c("response", "prob")
   ))
   if (predict.type == "prob" && !hasProperties(learner, "prob"))
     stopf("Trying to predict probs, but %s does not support that!", learner$id)
