@@ -55,7 +55,7 @@ train = function(learner, task, subset, weights = NULL) {
     weights = task$weights
   }
 
-  checkTaskCreationLearner(task, learner, weights)
+  checkLearnerBeforeTrain(task, learner, weights)
   pars$.weights = weights
 
   # only pass train hyper pars as basic rlearner in ...
@@ -68,30 +68,23 @@ train = function(learner, task, subset, weights = NULL) {
     learner.model = makeNoFeaturesModel(targets = task$env$data[subset, tn], task.desc = task$task.desc)
     time.train = 0
   } else {
-    opt.slo = getMlrOption("show.learner.output")
-    opt.ole = getMlrOption("on.learner.error")
+    opts = getLearnerOptions(learner, c("show.learner.output", "on.learner.error", "on.learner.warning"))
     # set the seed
     debug.seed = getMlrOption("debug.seed", NULL)
     if (!is.null(debug.seed))
       set.seed(debug.seed)
     # for optwrappers we want to see the tuning / varsel logging
-    # FIXME is case really ok for optwrapper? can we supppress then too?
-    if (opt.slo || inherits(learner, "OptWrapper"))
-      fun1 = identity
-    else
-      fun1 = capture.output
-    if (opt.ole == "stop")
-      fun2 = identity
-    else
-      fun2 = function(x) try(x, silent = TRUE)
-    old.warn.opt = getOption("warn")
-    on.exit(options(warn = old.warn.opt))
-    if (getMlrOption("on.learner.warning") == "quiet") {
+    # FIXME: is case really ok for optwrapper? can we supppress then too?
+    fun1 = if (opts$show.learner.output || inherits(learner, "OptWrapper")) identity else capture.output
+    fun2 = if (opts$on.learner.error == "stop") identity else function(x) try(x, silent = TRUE)
+    if (opts$on.learner.warning == "quiet") {
+      old.warn.opt = getOption("warn")
+      on.exit(options(warn = old.warn.opt))
       options(warn = -1L)
     }
     st = system.time(fun1(learner.model <- fun2(do.call(trainLearner, pars))), gcFirst = FALSE)
     # was there an error during training? maybe warn then
-    if(is.error(learner.model) && opt.ole == "warn")
+    if(is.error(learner.model) && opts$on.learner.error == "warn")
       warningf("Could not train learner %s: %s", learner$id, as.character(learner.model))
     time.train = as.numeric(st[3L])
   }
