@@ -17,7 +17,7 @@ tuneCMAES = function(learner, task, resampling, measures, par.set, control, opt.
   ctrl.cmaes = insert(ctrl.cmaes, control$extra.args)
   cx = function(x) convertXMatrixCols(x, par.set)
 
-  or = cma_es(par = start, fn = tunerFitnFunVectorized, lower = low, upper = upp, control = ctrl.cmaes,
+  or = cmaes::cma_es(par = start, fn = tunerFitnFunVectorized, lower = low, upper = upp, control = ctrl.cmaes,
     learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
     convertx = cx, remove.nas = FALSE)
