@@ -10,7 +10,7 @@ tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.
   start = convertStartToNumeric(start, par.set)
   ctrl.gensa = control$extra.args
   cx = function(x) convertXNumeric(x, par.set)
-  or = GenSA(par = start, fn = tunerFitnFun, lower = low, upper = upp, control = ctrl.gensa,
+  or = GenSA::GenSA(par = start, fn = tunerFitnFun, lower = low, upper = upp, control = ctrl.gensa,
     learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
     convertx = cx, remove.nas = FALSE)
