@@ -9,20 +9,20 @@ setDefaultImputeVal = function(control, measures) {
       Inf
   }
   if (is.null(control$impute.val))
-    control$impute.val = sapply(measures, getDefVal)
+    control$impute.val = vnapply(measures, getDefVal)
   return(control)
 }
 
 
 ##### tuning #####
 makeOptPathDFFromMeasures = function(par.set, measures) {
-  ns = sapply(measures, measureAggrName)
-  if (any(duplicated(ns)))
+  ns = vcapply(measures, measureAggrName)
+  if (anyDuplicated(ns))
     stop("Cannot create OptPath, measures do not have unique ids!")
-  if (length(intersect(ns, names(par.set$pars))) > 0 ||
-    length(intersect(ns, getParamIds(par.set, repeated = TRUE, with.nr = TRUE))) > 0)
+  if (length(intersect(ns, names(par.set$pars))) > 0L ||
+    length(intersect(ns, getParamIds(par.set, repeated = TRUE, with.nr = TRUE))) > 0L)
     stop("Cannot create OptPath, measures ids and dimension names of input space overlap!")
-  minimize = sapply(measures, function(m) m$minimize)
+  minimize = vlapply(measures, function(m) m$minimize)
   makeOptPathDF(par.set, ns, minimize, add.transformed.x = FALSE,
     include.error.message = TRUE, include.exec.time = TRUE)
 }
@@ -49,6 +49,7 @@ logFunSelFeatures = function(learner, task, resampling, measures, par.set, contr
 
 featuresToLogical = function(vars, all.vars) {
   if (is.list(vars)) {
+    # FIXME: use asMatrixCols / asMatrixRows
     y = t(sapply(vars, function(x) all.vars %in% x))
     colnames(y) = all.vars
   } else {
@@ -68,7 +69,7 @@ logicalToFeatures = function(x, all.vars) {
   if (is.matrix(x)) {
     if (missing(all.vars))
       all.vars = colnames(x)
-    lapply(1:nrow(x), function(i) all.vars[x[i,]])
+    lapply(seq_row(x), function(i) all.vars[x[i,]])
   } else {
     if (missing(all.vars))
       all.vars = names(x)
@@ -85,19 +86,3 @@ compare.diff = function(state1, state2, control, measure, threshold) {
   ifelse(measure$minimize, 1, -1) * (state1$y[1] - state2$y[1]) > threshold
 }
 
-# FIXME: remove this when PH is fixed on CRAN
-addOptPathElFixed = function(op, x, y, dob = getOptPathLength(op) + 1L, eol = as.integer(NA),
-    error.message = NA_character_, exec.time = NA_real_, extra = NULL,
-    check.feasible = !op$add.transformed.x) {
-
-  addOptPathEl(op = op, x = x, y = y, dob = dob, eol = eol, error.message = error.message,
-    exec.time = exec.time, extra = extra, check.feasible = check.feasible)
-  types = getParamTypes(op$par.set, df.cols = TRUE, df.discretes.as.factor = FALSE)
-  # print(types)
-  for (j in seq_along(types)) {
-    type = types[j]
-    g = get(sprintf("as.%s", type))
-    op$env$path[, j] = g(op$env$path[, j])
-  }
-}
-
