@@ -16,12 +16,6 @@ test_that("cv instance works", {
     expect_true(max(i2) <= 25)
     expect_equal(sort(c(unique(i1), i2)), 1:25)
   }
-  # check that resampling is really stochastic
-  if (interactive()) {
-    rin1 = makeResampleInstance(makeResampleDesc("CV", iters = 2L), size = 500)
-    rin2 = makeResampleInstance(makeResampleDesc("CV", iters = 2L), size = 500)
-    expect_true(!all(sort(rin1$test.inds[[1]]) == sort(rin2$test.inds[[1]])))
-  }
 })
 
 test_that("cv resampling works", {
@@ -34,10 +28,3 @@ test_that("cv resampling works", {
 
   testCV("classif.rpart", multiclass.df, multiclass.target, tune.train = tt, tune.predict = tp, parset = parset)
 })
-
-
-
-
-
-
-
